# `react-bootstrap-jalali-calendar`

This package created specifically for `react-bootstrap` which will help you to easily add Jalali calendar in your project without any changing in the code.

<span><svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-emoji-heart-eyes" viewBox="0 0 16 16">
<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/>
<path d="M11.315 10.014a.5.5 0 0 1 .548.736A4.498 4.498 0 0 1 7.965 13a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .548-.736h.005l.017.005.067.015.252.055c.215.046.515.108.857.169.693.124 1.522.242 2.152.242.63 0 1.46-.118 2.152-.242a26.58 26.58 0 0 0 1.109-.224l.067-.015.017-.004.005-.002zM4.756 4.566c.763-1.424 4.02-.12.952 3.434-4.496-1.596-2.35-4.298-.952-3.434zm6.488 0c1.398-.864 3.544 1.838-.952 3.434-3.067-3.554.19-4.858.952-3.434z"/>
</svg></span> 
Enjoy coding ... 
---

`font-family: dana`

<img src="D:\projects\NPM\my-test\datepicker.jpg"/>

## Required

This package created with

```text
npm install react-bootstrap bootstrap
npm install moment-jalaali
```

Please fill free If you encounter an issue using this product, be sure to notify us from issues part.

_We will do our best to improve and cooperate with you_

##index.js
Make your project RTL
```js
import React from 'react';
import ReactDOM from 'react-dom/client';
import App from './App';
import reportWebVitals from './reportWebVitals';
import 'bootstrap/dist/css/bootstrap.rtl.min.css';
import {ThemeProvider} from "react-bootstrap";

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(
    <ThemeProvider dir="rtl">
        <App/>
    </ThemeProvider>
);

reportWebVitals();
```

##index.html
Add `dir="rtl"` to your html
```html
<!DOCTYPE html>
<html lang="en" dir="rtl">
...
</html>
```

## Installation 🚀

In the project directory terminal, you can run:

### `npm install react-bootstrap-jalali-calendar`

## Output

When you click on the day, you will get this json.

_Event property default is `undefined`_

```json
{
  "date": "1400/2/14",
  "day": 14,
  "event": {
    "day": 8,
    "description": "۸ تیر عید سعید قربان",
    "isHoliday": true
  },
  "gregorian": "2021-5-4",
  "month": 2,
  "name": "Tue",
  "year": 1400
}
```

## Simple input

Easy to use

```js
import React from 'react';
import {useState} from "react";
import Datepicker from 'react-bootstrap-jalali-calendar';

const App = () => {
    //optional: with default value
    const options = {
        template: 'floating',
        formControlSize: "",
        hideFormControlLabel: false,
        hideTodayButton: false,
        stopChangingYears: false,
        calendarHeaderColor: "primary",
        hideToolsBar: false,
        calendarToolsColor: "light",
    }
    //you can remove it 
    
    //with default value
    const [date, setDate] = useState("1367/3/4");

    return (
        <>
            <Datepicker name={'test'}
                        options={options}
                        value={date}
                        callback={(day) => setDate(day.date)}/>
        </>
    )
};

export default App;
```

## Multiple inputs

Multiple used

```js
import React from 'react';
import {useState} from "react";
import Datepicker from 'react-bootstrap-jalali-calendar';

const App = () => {
    const [date, setDate] = useState("");
    //with default value
    const [date2, setDate2] = useState("1367/3/10");

    return (
        <div className={"row"}>
            <div className={'col-12 col-lg-6 mb-3 mb-lg-0'}>
                <Datepicker name={'test'}
                            value={date}
                            callback={(day) => setDate(day.date)}/>
            </div>

            <div className={'col-12 col-lg-6 mb-3 mb-lg-0'}>
                <Datepicker name={'test2'}
                            value={date2}
                            callback={(day) => setDate2(day.date)}/>
            </div>
        </div>
    )
};

export default App;
```

## Array inputs

Handle your array inputs

```js
import React from 'react';
import {useState} from "react";
import Datepicker from 'react-bootstrap-jalali-calendar';

const App = () => {
    const data = [
        {
            name: 'test3',
            value: ""
        },
        {
            name: 'test4',
            value: "1400/2/14"
        }
    ];

    const [items, handleItems] = useState(data);

    const setItemsValue = (item, date) => {
        const cloneItems = [...items];
        const findItemByName = cloneItems.find(x => x.name === item.name);
        if (findItemByName) {
            findItemByName.value = date;
        }
        handleItems(cloneItems);
    }

    return (
        <div className={"row"}>
            {
                items.map((item, index) => {
                    return <React.Fragment key={index}>
                        <div className={'col-12 col-lg-6 mb-3 mb-lg-0'}>
                            <Datepicker name={item.name}
                                        value={item.value}
                                        callback={(day) => setItemsValue(item, day.date)}/>
                        </div>
                    </React.Fragment>
                })
            }
        </div>
    )
};

export default App;
```

## Calendar events

Set your events on calendar easily

```js
import React from 'react';
import {useState} from "react";
import Datepicker from 'react-bootstrap-jalali-calendar';

const App = () => {
    //with default value
    const [date, setDate] = useState("1367/3/4");

    const events = [
        {
            year: 1402,
            data: [
                {
                    month: 4,
                    data: [
                        {
                            day: 8,
                            isHoliday: true,
                            description: '۸ تیر عید سعید قربان'
                        },
                        {
                            day: 16,
                            isHoliday: true,
                            description: '۱۶ تیر عید سعید غدیر خم [ ١٨ ذوالحجه ]'
                        }
                    ]
                },
                {
                    month: 5,
                    data: [
                        {
                            day: 5,
                            isHoliday: true,
                            description: '۵ اَمرداد تاسوعای حسینی [ ٩ محرم ]'
                        },
                        {
                            day: 6,
                            isHoliday: true,
                            description: '۶ اَمرداد عاشورای حسینی [ ١٠ محرم ]'
                        }
                    ]
                }
            ]
        }
    ];

    return (
        <>
            <Datepicker name={'test'}
                        events={events}
                        value={date}
                        callback={(day) => setDate(day.date)}/>
        </>
    )
};

export default App;
```

## `Datepicker` Properties 📄

| Name          | Default    | Required | Description
| ------------- | ---------- | -------- | -----------
| `callback`    | `null`     | Yes      | calendar method to pass the value
| `value`       | `null`    | Yes      | input value
| `name`        | `null`     | Yes      | input name
| `id`          | `{name}`   | No       | input id - default is {name} if empty
| `label`       | `{name}`   | No       | input id - default is {name} if empty
| `placeholder` | `{name}`   | No       | input id - default is {name} if empty
| `disabled`    | `false`    | No       | disable input
| `events`      | `[array]` | No       | calendar events

## `Calendar` Options 📄

###BootstrapMainColors
```json
[
  "danger",
  "primary",
  "dark",
  "info",
  "light",
  "secondary",
  "success",
  "warning"
]
```

| Name                  | Default    | Options                  | Description
| --------------------- | ---------- | -----------------------  | -----------
| `template`            | `floating` | `floating` `formControl` | Bootstrap input type
| `formControlSize`     | `""`       | `lg` `sm` `""`           | Bootstrap input size if <div>`{template: "formControl"}`</div>
| `hideFormControlLabel`| `false`    |                          | Hide input label if <div>`{template: "formControl"}`</div>
| `hideTodayButton`     | `false`    |                          | Hide today button from the calendar                          
| `stopChangingMonths`  | `false`    |                          | Disable changing month, it will effect years                         
| `stopChangingYears`   | `false`    |                          | Disable changing years                         
| `hideToolsBar`        | `false`    |                          | Hide calendar toolbar include: `change years`, `change month`
| `calendarHeaderColor` | `primary`  | BootstrapMainColors      | Select from bootstrap main colors
| `calendarToolsColor`  | `light`    | BootstrapMainColors      | Select from bootstrap main colors

## License

[MIT](./LICENSE)